app <- ShinyDriver$new("../", seed = 1)
app$snapshotInit("testWrongInputProposeNewPoint")

app$setInputs(tabs = "spotConfig")
try(app$setInputs(tabs = "runMode"), silent = T)
app$setInputs(runCreateDOE = "click")
app$setInputs(evaluateData = "click")
app$setInputs(tabs = "spotConfig")
app$setInputs(xml_optimLHDcontrol = TRUE)
app$setInputs(xml_optimLHDcontrolfunEvals = "chara")
try(app$setInputs(tabs = "runMode"), silent = T)
app$setInputs(proposeNewPoint = "click")
app$snapshot(list(output = "resultTable"))
